Modules
Macros
- lazy_
static - rindexer_
error - Constructs an event at the error level.
- rindexer_
info - Constructs an event at the info level.
Structs
- ABIItem
- Async
CsvAppender - Graphql
Override Settings - Header
Map - A set of HTTP headers
- Indexer
NoCode Details - Indexing
Details - PgType
- A Postgres type.
- Postgres
Client - Start
Details - Start
NoCode Details
Enums
Traits
- Future
Ext - An extension trait for
Futures that provides a variety of convenient adapters. - Rindexer
Colorize - The trait that enables something to be given color.
- ToSql
- A trait for types that can be converted into Postgres values.
Functions
- drop_
tables_ for_ indexer_ sql - format_
all_ files_ for_ project - Formats all Rust source files in the given folder using
cargo fmt. - generate_
graphql_ queries - generate_
random_ id - initiate_
shutdown - is_
running - load_
env_ from_ project_ path - public_
read_ env_ value - setup_
info_ logger - setup_
postgres - start_
rindexer - start_
rindexer_ no_ code - write_
file
Attribute Macros
- async_
trait - rindexer_
main - Marks async function to be executed by the selected runtime. This macro
helps set up a
Runtimewithout requiring the user to use Runtime or Builder directly.